==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/de_DE.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Aufgaben",
    "Personal" : "Persönlich",
    "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
    "You created calendar {calendar}" : "Sie haben den Kalender {calendar} erstellt",
    "{actor} deleted calendar {calendar}" : "{actor} hat den Kalender {calendar} gelöscht",
    "You deleted calendar {calendar}" : "Sie haben den Kalender {calendar} gelöscht",
    "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
    "You updated calendar {calendar}" : "Sie haben hat den Kalender {calendar} aktualisiert",
    "You shared calendar {calendar} as public link" : "Sie haben den Kalender {calendar} als öffentlichen Link geteilt",
    "You removed public link for calendar {calendar}" : "Sie haben den öffentlichen Link für Kalender {calendar} entfernt",
    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit Ihnen geteilt",
    "You shared calendar {calendar} with {user}" : "Sie haben den Kalender {calendar} mit {user} geteilt",
    "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit Ihnen",
    "You unshared calendar {calendar} from {user}" : "Sie teilen den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
    "You shared calendar {calendar} with group {group}" : "Sie haben den Kalender {calendar} mit der Gruppe {group} geteilt",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Sie teilen den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} erstellt",
    "You created event {event} in calendar {calendar}" : "Sie haben das Ereignis {event} im Kalender {calendar} erstellt",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} gelöscht",
    "You deleted event {event} from calendar {calendar}" : "Sie haben das Ereignis {event} im Kalender {calendar} gelöscht",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} aktualisiert",
    "You updated event {event} in calendar {calendar}" : "Sie haben das Ereignis {event} im Kalender {calendar} aktualisiert",
    "{actor} created todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
    "You created todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erstellt",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "You deleted todo {todo} from list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "You updated todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
    "You solved todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erledigt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "You reopened todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
    "A calendar <strong>event</strong> was modified" : "Ein Kalender-<strong>Ereignis</strong> wurde bearbeitet",
    "A calendar <strong>todo</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde bearbeitet",
    "Contact birthdays" : "Geburtstage von Kontakten",
    "%s via %s" : "%s über %s",
    "Invitation canceled" : "Einladung abgebrochen",
    "Hello %s," : "Hallo %s,",
    "The meeting »%s« with %s was canceled." : "Der Termin »%s« mit %s wurde abgesagt.",
    "Invitation updated" : "Einladung aktualisiert",
    "The meeting »%s« with %s was updated." : "Der Termin »%s« mit %s wurde aktualisiert.",
    "%s invited you to »%s«" : "%s hat Sie zu »%s« eingeladen",
    "When:" : "Wann:",
    "Where:" : "Wo:",
    "Description:" : "Beschreibung:",
    "Link:" : "Link:",
    "Contacts" : "Kontakte",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-Endpunkt",
    "Technical details" : "Technische Details",
    "Remote Address: %s" : "Entfernte Adresse: %s",
    "Request ID: %s" : "Anfragekennung: %s",
    "CalDAV server" : "CalDAV-Server",
    "Send invitations to attendees" : "Einladungen an die Teilnehmer versenden",
    "Please make sure to properly set up the email settings above." : "Stellen Sie sicher, dass die obigen E-Mail-Einstellungen korrekt sind.",
    "Automatically generate a birthday calendar" : "Automatischen einen Kalender für Geburtstage erstellen",
    "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einem Hintergrund-Auftrag erstellt",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es ein wenig dauern bis zur Anzeige."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/de_DE.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Aufgaben",
    "Personal" : "Persönlich",
    "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
    "You created calendar {calendar}" : "Sie haben den Kalender {calendar} erstellt",
    "{actor} deleted calendar {calendar}" : "{actor} hat den Kalender {calendar} gelöscht",
    "You deleted calendar {calendar}" : "Sie haben den Kalender {calendar} gelöscht",
    "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
    "You updated calendar {calendar}" : "Sie haben hat den Kalender {calendar} aktualisiert",
    "You shared calendar {calendar} as public link" : "Sie haben den Kalender {calendar} als öffentlichen Link geteilt",
    "You removed public link for calendar {calendar}" : "Sie haben den öffentlichen Link für Kalender {calendar} entfernt",
    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit Ihnen geteilt",
    "You shared calendar {calendar} with {user}" : "Sie haben den Kalender {calendar} mit {user} geteilt",
    "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit Ihnen",
    "You unshared calendar {calendar} from {user}" : "Sie teilen den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
    "You shared calendar {calendar} with group {group}" : "Sie haben den Kalender {calendar} mit der Gruppe {group} geteilt",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Sie teilen den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} erstellt",
    "You created event {event} in calendar {calendar}" : "Sie haben das Ereignis {event} im Kalender {calendar} erstellt",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} gelöscht",
    "You deleted event {event} from calendar {calendar}" : "Sie haben das Ereignis {event} im Kalender {calendar} gelöscht",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} aktualisiert",
    "You updated event {event} in calendar {calendar}" : "Sie haben das Ereignis {event} im Kalender {calendar} aktualisiert",
    "{actor} created todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
    "You created todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erstellt",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "You deleted todo {todo} from list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "You updated todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
    "You solved todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erledigt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "You reopened todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
    "A calendar <strong>event</strong> was modified" : "Ein Kalender-<strong>Ereignis</strong> wurde bearbeitet",
    "A calendar <strong>todo</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde bearbeitet",
    "Contact birthdays" : "Geburtstage von Kontakten",
    "%s via %s" : "%s über %s",
    "Invitation canceled" : "Einladung abgebrochen",
    "Hello %s," : "Hallo %s,",
    "The meeting »%s« with %s was canceled." : "Der Termin »%s« mit %s wurde abgesagt.",
    "Invitation updated" : "Einladung aktualisiert",
    "The meeting »%s« with %s was updated." : "Der Termin »%s« mit %s wurde aktualisiert.",
    "%s invited you to »%s«" : "%s hat Sie zu »%s« eingeladen",
    "When:" : "Wann:",
    "Where:" : "Wo:",
    "Description:" : "Beschreibung:",
    "Link:" : "Link:",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "More options ..." : "Weitere Optionen…",
    "More options at %s" : "Weitere Optionen unter %s",
    "Contacts" : "Kontakte",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-Endpunkt",
    "Technical details" : "Technische Details",
    "Remote Address: %s" : "Entfernte Adresse: %s",
    "Request ID: %s" : "Anfragekennung: %s",
    "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren Ihres Teilnehmerstatus aufgetreten.",
    "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
    "Are you accepting the invitation?" : "Die Einladung annehmen?",
    "Tentative" : "Vorläufig",
    "Save" : "Speichern",
    "Your attendance was updated successfully." : "Ihr Teilnehmerstatus wurde aktualisiert.",
    "CalDAV server" : "CalDAV-Server",
    "Send invitations to attendees" : "Einladungen an die Teilnehmer versenden",
    "Please make sure to properly set up the email settings above." : "Stellen Sie sicher, dass die obigen E-Mail-Einstellungen korrekt sind.",
    "Automatically generate a birthday calendar" : "Automatischen einen Kalender für Geburtstage erstellen",
    "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einem Hintergrund-Auftrag erstellt",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es ein wenig dauern bis zur Anzeige."
},
"nplurals=2; plural=(n != 1);");
